"""Copyright 2016-2017 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License."""


from traceutils.record.record import Record


class MemoryAccessRecord(Record):
    """Memory access trace record."""

    RW = "rw"
    SIZE = "size"
    ATTRIB = "attrib"
    ADDR = "addr"
    DATA = "data"

    def __init__(self, time, scale, rw, size, attrib, addr, data):
        """Default constructor."""
        Record.__init__(self, time, scale)
        self[self.RW] = rw
        self[self.SIZE] = int(size)
        self[self.ATTRIB] = attrib
        self[self.ADDR] = int(addr, 16)
        self[self.DATA] = int(data, 16)

    def get_rw(self):
        """Returns read/write access type."""
        return self[self.RW]

    def get_size(self):
        """Returns the size of the data transfer in bytes (1, 2, 4, 8)."""
        return self[self.SIZE]

    def get_attrib(self):
        """Returns the optional access attribute."""
        return self[self.ATTRIB]

    def get_addr(self):
        """Returns the virtual address used to access memory in hexadecimal format."""
        return self[self.ADDR]

    def get_data(self):
        """Returns the hexadecimal value of data transferred."""
        return self[self.DATA]
